summaryrefslogtreecommitdiffstats
path: root/kmail/objecttreeparser.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /kmail/objecttreeparser.h
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kmail/objecttreeparser.h')
-rw-r--r--kmail/objecttreeparser.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/objecttreeparser.h b/kmail/objecttreeparser.h
index b864ea618..f9e71427a 100644
--- a/kmail/objecttreeparser.h
+++ b/kmail/objecttreeparser.h
@@ -169,13 +169,13 @@ namespace KMail {
KMail::CSSHelper * cssHelper() const { return mCSSHelper; }
/** Parse beginning at a given node and recursively parsing
- the tqchildren of that node and it's next sibling. */
+ the children of that node and it's next sibling. */
// Function is called internally by "parseMsg(KMMessage* msg)"
// and it will be replaced once KMime is alive.
void parseObjectTree( partNode * node );
private:
/** Standard tqchildren handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );
@@ -169,13 +169,13 @@ namespace KMail {
void parseObjectTree( partNode * node );
private:
- /** Standard tqchildren handling a.k.a. multipart/mixed (w/o
+ /** Standard children handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );